unit CoolEdit;
{
                                   \\\\\/////
                                   /  _   _  \
                                  (| (.) (.) |)
 _______________________________.OOOo__( )__oOOO.______________________________
|                                                                              |
|                                       CoolEdit                                 |
|                                  by Franky Brandt                            |
|                         Email franky.brandt@planetinternet.be                |
|                                     Homepage:                                |
|                     Http://home2.planetinternet.be/fbrandt/                  |
|                                                                              |
|                                                                              |
|_______________________________.oooO__________________________________________|
                                (   )        Oooo.
                                 \ (         (   )
                                  \_)         ) /
                                             (_/                                 }




interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, DsgnIntf,CoolEditAbout;

type
  TCoolEditType = (Both,Numeric,Alpha);

  TAboutProperty = class(TPropertyEditor)
  public
    function  GetValue      : String; override;
    function  GetAttributes : TPropertyAttributes; override;
    procedure Edit; override;
  End;

  TCoolEdit = class(TEdit)
  private
    FAbout:TAboutProperty;
    fSelectNext:Boolean;
    FType:TCoolEditType;
    procedure SetType( Value: TCoolEditType );
    procedure SetSelectNext(Value:Boolean);
    procedure SelectNext;
  protected
    fOnSelectNext:TNotifyEvent;
    procedure KeyPress( var Key: Char ); override;
  public
    constructor Create( AOwner : TComponent ); override;
  published
    property About: TAboutProperty read FAbout write FAbout;
    property SelectNextControl:Boolean read fSelectNext write SetSelectNext default True;
    property TextType: TCoolEditType read FType write SetType ;
    property OnSelectNext:TNotifyevent read fOnSelectNext write fOnSelectNext;
  end;

Const cmpVERSION: String = '0.02';

procedure Register;

implementation

{ Register component }

procedure Register;
begin
  RegisterPropertyEditor(TypeInfo(TAboutProperty), TCoolEdit, 'About',
                         TAboutProperty);
  RegisterComponents('Standard', [TCoolEdit]);
end;

{ TCoolEditAbout }

procedure TAboutProperty.Edit;
begin
  with TfrmCoolEditAbout.Create(Application) do
  try
    lblVersion.Caption := 'Version ' + cmpVersion;
    ShowModal;
  finally
    Free;
  end;
end;

function  TAboutProperty.GetAttributes : TPropertyAttributes;
begin
  Result := [paMultiSelect, paDialog, paReadOnly];
end;

function  TAboutProperty.GetValue : String;
begin
  Result := cmpVersion;
end;

{ TCoolEdit }

constructor TCoolEdit.Create(AOwner: TComponent);
begin
  inherited;
  fSelectNext := True;
end;

procedure TCoolEdit.SelectNext;
Begin
 if Assigned(fOnSelectNext) then
  fOnSelectNext(self);
End;

procedure TCoolEdit.KeyPress( var Key: Char );
begin
 inherited;
 if key = #13 then
 begin
  key := char(vk_cancel);
  If fSelectNext Then
  Begin
   Try
    GetParentForm(Self).Perform(WM_NEXTDLGCTL, 0, 0);
    fOnSelectNext(self);
   Except;
   End;
  End;
 end;
 If FType = Alpha Then
    begin
      If (Key in ['0'..'9']) Then Key:=#0;
    end else
 If FType = Numeric Then
    begin
      If (Key in ['A'..'Z'])or(Key in ['a'..'z']) Then Key:=#0;
    end;
end;

procedure TCoolEdit.SetSelectNext(Value: Boolean);
begin
 fSelectNext := Value;
end;

procedure TCoolEdit.SetType(Value: TCoolEditType);
begin
 fType := Value;
end;

end.
